@@ -41,7 +41,7 @@ analogy <- function(formula) {
 #' @param mode specify the type of resulting object.
 #' @return a `matrix` of cosine similarity scores when `mode = "numeric"` or of 
 #'   words sorted in descending order by the similarity scores when `mode = "character"`.
-#'   When `words` is a named numeric vector, word (or document) vectors are weighted and summed 
+#'   When `targets` is a named numeric vector, word (or document) vectors are weighted and summed 
 #'   before computing similarity scores.
 #' @export
 #' @seealso [probability()]
@@ -99,14 +99,15 @@ similarity <- function(x, targets, layer = c("words", "documents"),
 #' @param targets words for which probabilities are computed.
 #' @param layer the layer based on which probabilities are computed.
 #' @param mode specify the type of resulting object.
+#' @param ... passed to `as.matrix()`.
 #' @return a matrix of words or documents sorted in descending order by the probability 
 #'   scores when `mode = "character"`; a matrix of the probability scores when `mode = "numeric"`.
-#'   When `words` is a named numeric vector, probability scores are weighted by
+#'   When `targets` is a named numeric vector, probability scores are weighted by
 #'   the values.
 #' @export
 #' @seealso [similarity()]
 probability <- function(x, targets, layer = c("words", "documents"),
-                        mode = c("character", "numeric")) {
+                        mode = c("character", "numeric"), ...) {
     
     layer <- match.arg(layer)
     mode <- ifelse(mode == "words", "character", mode) # for < v0.6.0
@@ -144,7 +145,7 @@ probability <- function(x, targets, layer = c("words", "documents"),
     }
     targets <- targets[b]
     
-    values <- as.matrix(x, layer = layer, normalize = FALSE)
+    values <- as.matrix(x, layer = layer, normalize = FALSE, ...)
     e <- exp(tcrossprod(values, x$weights[names(targets),, drop = FALSE]))
     prob <- e / (e + 1) # sigmoid function
     
@@ -182,11 +183,14 @@ perplexity <- function(x, targets, data) {
     if (!is.tokens(data) && !is.dfm(data))
         stop("data must be a tokens or dfm")
     data <- dfm(data, remove_padding = TRUE, tolower = x$tolower)
-    
+
     p <- probability(x, targets, mode = "numeric")
-    pred <- crossprod(t(dfm_match(dfm_weight(data, "prop"), rownames(p))), p)
-    tri <- Matrix::mat2triplet(dfm_match(data, colnames(pred)))
-    exp(-sum(tri$x * log(pred[cbind(tri$i, tri$j)])) / sum(tri$x))
+    pred <- dfm_match(data, rownames(p)) %*% p
+    pred <- pred / rowSums(pred)
+    
+    data <- dfm_match(data, colnames(pred))
+    data <- Matrix::mat2triplet(data)
+    exp(-sum(data$x * log(pred[cbind(data$i, data$j)])) / sum(data$x))
 }
 
 get_threads <- function() {
